# Source this to set the ellipsoid parameters
OBL="-e  1 3/4 3 0"
SETA="-e 1 1   2 1"
SET="-e  1 3/2 1 2"
PRO="-e  1 3   0 3"
SPHA="-e 1 0 3 0"
SPHB="-e 1 0 2 1"
SPHC="-e 1 0 1 2"
SPHD="-e 1 0 0 3"
HU="-e   1 7577279780/1130005142289 1942065235 6378137"
PHU="-e  1 30308952520/4489860107041 3178376 971037955"
OBLX="-e 1 150/197 49 1"
PROX="-e 1 150/53 1 49"
WGS84="-e 1 124/18523 1 0"
T321="-e 1 2 3 5"
ORIG="-e 1 3801/10000 3600 201"
BILL="-e 1 10101/10000 9900 201"
